@@ -66,6 +66,90 @@ GH_Mixture_Model* gh_create_model(arma::mat* Xp,int G, int model_id, int model_t
  }
 }
 
+
+
+void set_model_defaults(std::unique_ptr<GH_Mixture_Model> & m, 
+                        int model_type,
+                        int in_m_iter_max,
+                        double in_m_tol )
+{
+  
+  switch (model_type)
+    {
+      case 4:{
+        if(in_m_iter_max != 0){
+          m->set_m_iterations(in_m_iter_max,in_m_tol);
+        }
+        else{
+          m->set_defaults();
+        } 
+        break;    
+      }
+      case 12:{
+        if(in_m_iter_max != 0){
+          m->set_m_iterations(in_m_iter_max,in_m_tol);
+        }
+        else{
+          m->set_defaults();
+        } 
+        break; 
+      }
+      case 7:{
+        if(in_m_iter_max != 0){
+          m->set_m_iterations(in_m_iter_max,in_m_tol);
+        }
+        else{
+          m->set_defaults();
+        } 
+        break; 
+      }
+      case 8:{
+        if(in_m_iter_max != 0){
+          m->set_m_iterations(in_m_iter_max,in_m_tol,arma::mat(m->p,m->p,arma::fill::eye));
+        }
+        else{
+          m->set_defaults();
+        } 
+        break; 
+      }
+      case 10:{
+        if(in_m_iter_max != 0){
+          m->set_m_iterations(in_m_iter_max,in_m_tol,arma::mat(m->p,m->p,arma::fill::eye));
+        }
+        else{
+          m->set_defaults();
+        } 
+      }
+      default:
+        break;
+    }
+
+}
+
+Rcpp::List create_result_list(std::unique_ptr<GH_Mixture_Model> & m, bool check_na_)
+/*
+  Creates the return list object that is pushed out to the R from C++. 
+*/
+{
+  Rcpp::List result_list = Rcpp::List::create(Rcpp::Named("mus") = m->mus, 
+                                          Rcpp::Named("alphas") = m->alphas, 
+                                          Rcpp::Named("sigs") = m->sigs,
+                                          Rcpp::Named("G") = m->G, 
+                                          Rcpp::Named("omegas") = m->omegas,
+                                          Rcpp::Named("lambdas") = m->lambdas,
+                                          Rcpp::Named("zigs") = m->zi_gs,
+                                          Rcpp::Named("pi_gs") = m->pi_gs,
+                                          Rcpp::Named("n_gs") = m->n_gs,
+                                          Rcpp::Named("log_dets") = m->log_dets,
+                                          Rcpp::Named("logliks") = m->logliks);
+
+  if(check_na_){
+    result_list["X"] = m->data.t(); 
+  }
+
+  return result_list; 
+}
+
 // WRAPPERS 
 
 // [[Rcpp::export]]
@@ -132,55 +216,8 @@ Rcpp::List main_loop_gh(arma::mat X, // data
     if(NA_check){
 
       // check to see if model_id is any of the special ones and set defaults, or pass in arguement. 
-      switch (model_type)
-      {
-        case 4:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol);
-          }
-          else{
-            m->set_defaults();
-          } 
-          break;    
-        }
-        case 12:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol);
-          }
-          else{
-            m->set_defaults();
-          } 
-          break; 
-        }
-        case 7:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol);
-          }
-          else{
-            m->set_defaults();
-          } 
-          break; 
-        }
-        case 8:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol,arma::mat(m->p,m->p,arma::fill::eye));
-          }
-          else{
-            m->set_defaults();
-          } 
-          break; 
-        }
-        case 10:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol,arma::mat(m->p,m->p,arma::fill::eye));
-          }
-          else{
-            m->set_defaults();
-          } 
-        }
-        default:
-          break;
-      }
+      set_model_defaults(m, model_type, in_m_iter_max, in_m_tol); 
+
       // phase 1
       m->EM_burn(t_burn); // defaults already set in here, although I should pull them out. in full function. 
       // phase 2. 
@@ -226,77 +263,24 @@ Rcpp::List main_loop_gh(arma::mat X, // data
 
     }
     else{
-      // perform intialization of params. 
-      m->M_step_props(); 
-      m->M_step_init_gaussian();
-      m->M_step_mus();
-      m->M_step_Ws();
-      
+    
 
       // check to see if model_id is any of the special ones and set defaults, or pass in arguement. 
-      switch (model_type)
-      {
-        case 4:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol);
-          }
-          else{
-            m->set_defaults();
-          } 
-          break;    
-        }
-        case 12:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol);
-          }
-          else{
-            m->set_defaults();
-          } 
-          break; 
-        }
-        case 7:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol);
-          }
-          else{
-            m->set_defaults();
-          } 
-          break; 
-        }
-        case 8:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol,arma::mat(m->p,m->p,arma::fill::eye));
-          }
-          else{
-            m->set_defaults();
-          } 
-          break; 
-        }
-        case 10:{
-          if(in_m_iter_max != 0){
-            m->set_m_iterations(in_m_iter_max,in_m_tol,arma::mat(m->p,m->p,arma::fill::eye));
-          }
-          else{
-            m->set_defaults();
-          } 
-        }
-        default:
-          break;
-      }
-      
-      m->m_step_sigs();
-      m->M_step_gamma(); 
-      m->track_lg_init(); 
+      set_model_defaults(m, model_type, in_m_iter_max, in_m_tol); 
 
-      // burn in
-      for(size_t iter = 0; iter < (size_t)t_burn; iter++){
-        m->E_step_latent();
-        m->M_step_props();
-        m->M_step_mus();
-        m->M_step_Ws(); 
-        m->m_step_sigs(); 
-        m->M_step_gamma(); 
-      }
+      // perform intialization of params. 
+      m->M_step_props(); 
+      m->M_step_init_gaussian(); 
+      m->track_lg_init(); 
+      m->E_step(); 
+      m->M_step_props(); 
+      m->E_step_latent();
+      m->M_step_props();
+      m->M_step_mus();
+      m->M_step_Ws(); 
+      m->m_step_sigs(); 
+      m->M_step_gamma();  
+      m->track_lg(false);     
 
       size_t nmax = (size_t)in_nmax; 
       bool convergence_check = false; 
@@ -311,16 +295,22 @@ Rcpp::List main_loop_gh(arma::mat X, // data
           m->nu = 1.0; 
         }
 
+        // set the previous state. 
+        m->set_previous_state(); 
+
         m->E_step(); 
+        m->M_step_props(); 
         m->E_step_latent();
-        m->M_step_props();
         m->M_step_mus();
         m->M_step_Ws(); 
         m->m_step_sigs(); 
         m->M_step_gamma(); 
 
+        // m->check_decreasing_loglik(); 
+        m->check_decreasing_loglik(&iter, nmax); 
+
         convergence_check = m->track_lg(iter < 5);
-        if(convergence_check){
+        if (convergence_check){
           // Rcpp::Rcout  << "Converged at Iteration " << iter << std::endl;  
           break; 
         }
@@ -330,40 +320,21 @@ Rcpp::List main_loop_gh(arma::mat X, // data
   catch(const std::exception& e)
   {
 
-
-    if(0 == std::string(e.what()).compare("logliklihood was infinite, back to previous step and returned results")){
-      Rcpp::List ret_val = Rcpp::List::create(
-                                          Rcpp::Named("mus") = m->mus,
-                                          Rcpp::Named("alphas") = m->alphas, 
-                                          Rcpp::Named("sigs") = m->sigs,
-                                          Rcpp::Named("G") = m->G, 
-                                          Rcpp::Named("omegas") = m->omegas,
-                                          Rcpp::Named("lambdas") = m->lambdas,
-                                          Rcpp::Named("zigs") = m->zi_gs,
-                                          Rcpp::Named("pi_gs") = m->pi_gs,
-                                          Rcpp::Named("n_gs") = m->n_gs,
-                                          Rcpp::Named("log_dets") = m->log_dets,
-                                          Rcpp::Named("logliks") = m->logliks);
-      return(ret_val);
+    // Rcpp::Rcout << "Error " << e.what() << " \n"; 
+    // check for bad logliklihood. 
+    if(is_string_comparison(e,"logliklihood was infinite, back to previous step and returned results"))
+    {
+      Rcpp::List ret_val = create_result_list(m, NA_check); 
+      return ret_val;
     }
 
+    // if all else fails, check for errors. 
     return Rcpp::List::create(Rcpp::Named("Error") = e.what()); 
   }
 
-    Rcpp::List ret_val = Rcpp::List::create(
-                                            Rcpp::Named("mus") = m->mus, 
-                                            Rcpp::Named("alphas") = m->alphas, 
-                                            Rcpp::Named("sigs") = m->sigs,
-                                            Rcpp::Named("G") = m->G, 
-                                            Rcpp::Named("omegas") = m->omegas,
-                                            Rcpp::Named("lambdas") = m->lambdas,
-                                            Rcpp::Named("zigs") = m->zi_gs,
-                                            Rcpp::Named("pi_gs") = m->pi_gs,
-                                            Rcpp::Named("n_gs") = m->n_gs,
-                                            Rcpp::Named("log_dets") = m->log_dets,
-                                            Rcpp::Named("logliks") = m->logliks);
-
-  return ret_val;
+    // create return object and exit c++. 
+    Rcpp::List ret_val = create_result_list(m, NA_check); 
+    return ret_val;
 }
 
 
